"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createBlockCategoryGraphQL = void 0;
var _responses = require("@webiny/handler-graphql/responses");
const resolve = async fn => {
  try {
    return new _responses.Response(await fn());
  } catch (e) {
    return new _responses.ErrorResponse(e);
  }
};
const createBlockCategoryGraphQL = () => {
  return {
    type: "graphql-schema",
    schema: {
      typeDefs: /* GraphQL */`
                type PbBlockCategory {
                    createdOn: DateTime
                    createdBy: PbCreatedBy
                    name: String
                    slug: String
                    icon: String
                    description: String
                }

                input PbBlockCategoryInput {
                    name: String!
                    slug: String!
                    icon: String!
                    description: String!
                }

                # Response types
                type PbBlockCategoryResponse {
                    data: PbBlockCategory
                    error: PbError
                }

                type PbBlockCategoryListResponse {
                    data: [PbBlockCategory]
                    error: PbError
                }

                extend type PbQuery {
                    getBlockCategory(slug: String!): PbBlockCategoryResponse
                    listBlockCategories: PbBlockCategoryListResponse
                }

                extend type PbMutation {
                    createBlockCategory(data: PbBlockCategoryInput!): PbBlockCategoryResponse
                    updateBlockCategory(
                        slug: String!
                        data: PbBlockCategoryInput!
                    ): PbBlockCategoryResponse
                    deleteBlockCategory(slug: String!): PbBlockCategoryResponse
                }
            `,
      resolvers: {
        PbQuery: {
          getBlockCategory: async (_, args, context) => {
            return resolve(() => {
              return context.pageBuilder.getBlockCategory(args.slug);
            });
          },
          listBlockCategories: async (_, __, context) => {
            return resolve(() => context.pageBuilder.listBlockCategories());
          }
        },
        PbMutation: {
          createBlockCategory: async (_, args, context) => {
            return resolve(() => {
              return context.pageBuilder.createBlockCategory(args.data);
            });
          },
          updateBlockCategory: async (_, args, context) => {
            return resolve(() => {
              return context.pageBuilder.updateBlockCategory(args.slug, args.data);
            });
          },
          deleteBlockCategory: async (_, args, context) => {
            return resolve(() => {
              return context.pageBuilder.deleteBlockCategory(args.slug);
            });
          }
        }
      }
    }
  };
};
exports.createBlockCategoryGraphQL = createBlockCategoryGraphQL;

//# sourceMappingURL=blockCategories.gql.js.map