"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createPageElementsGraphQL = void 0;
var _resolve = _interopRequireDefault(require("./utils/resolve"));
const createPageElementsGraphQL = () => {
  return {
    type: "graphql-schema",
    schema: {
      typeDefs: /* GraphQL */`
                type PbPageElement {
                    id: ID
                    createdOn: DateTime
                    createdBy: PbCreatedBy
                    name: String
                    type: String
                    content: JSON
                }

                input PbCreatePageElementInput {
                    name: String!
                    type: String!
                    content: JSON!
                }

                input PbUpdatePageElementInput {
                    name: String
                    type: String
                    content: JSON
                }

                # Response types
                type PbPageElementResponse {
                    data: PbPageElement
                    error: PbError
                }

                type PbPageElementListResponse {
                    data: [PbPageElement]
                    error: PbError
                }

                extend type PbQuery {
                    listPageElements: PbPageElementListResponse
                    getPageElement(id: ID!): PbPageElementResponse
                }

                extend type PbMutation {
                    createPageElement(data: PbCreatePageElementInput!): PbPageElementResponse
                    updatePageElement(
                        id: ID!
                        data: PbUpdatePageElementInput!
                    ): PbPageElementResponse
                    deletePageElement(id: ID!): PbDeleteResponse
                }
            `,
      resolvers: {
        PbQuery: {
          getPageElement: async (_, args, context) => {
            return (0, _resolve.default)(() => {
              return context.pageBuilder.getPageElement(args.id);
            });
          },
          listPageElements: async (_, __, context) => {
            return (0, _resolve.default)(() => {
              return context.pageBuilder.listPageElements();
            });
          }
        },
        PbMutation: {
          createPageElement: async (_, args, context) => {
            return (0, _resolve.default)(() => {
              return context.pageBuilder.createPageElement(args.data);
            });
          },
          updatePageElement: async (_, args, context) => {
            return (0, _resolve.default)(() => {
              return context.pageBuilder.updatePageElement(args.id, args.data);
            });
          },
          deletePageElement: async (_, args, context) => {
            return (0, _resolve.default)(async () => {
              await context.pageBuilder.deletePageElement(args.id);
              return true;
            });
          }
        }
      }
    }
  };
};
exports.createPageElementsGraphQL = createPageElementsGraphQL;

//# sourceMappingURL=pageElements.gql.js.map